import { h } from '@stencil/core/internal/client';
export { setAssetPath, setPlatformOptions } from '@stencil/core/internal/client';
export * from '@material/select';
import { classNames } from '@mdc-stencil/common';
import { Menu } from '@mdc-stencil/menu';

const Select = (props, children) => {
  const { class: className, filled, required, disabled, noLabel, withLeadingIcon, kind, ...rest } = props;
  return (h("div", { class: {
      'mdc-select': true,
      'mdc-select--filled': filled === true,
      'mdc-select--required': required === true,
      'mdc-select--disabled': disabled === true,
      'mdc-select--no-label': noLabel === true,
      'mdc-select--with-leading-icon': withLeadingIcon === true,
      [`mdc-select--${kind}`]: kind !== undefined,
      ...classNames(className)
    }, ...rest }, children));
};
const SelectAnchor = (props, children) => {
  const { class: className, ...rest } = props;
  return (h("div", { class: {
      'mdc-select__anchor': true,
      ...classNames(className)
    }, ...rest }, children));
};
const SelectRipple = (props, children) => {
  const { class: className, ...rest } = props;
  return (h("span", { class: {
      'mdc-select__ripple': true,
      ...classNames(className)
    }, ...rest }, children));
};
const SelectSelectedTextContainer = (props, children) => {
  const { class: className, ...rest } = props;
  return (h("span", { class: {
      'mdc-select__selected-text-container': true,
      ...classNames(className)
    }, ...rest }, children));
};
const SelectSelectedText = (props, children) => {
  const { class: className, ...rest } = props;
  return (h("span", { class: {
      'mdc-select__selected-text': true,
      ...classNames(className)
    }, ...rest }, children));
};
const SelectDropdownIcon = (props, children) => {
  const { class: className, ...rest } = props;
  return (h("span", { class: {
      'mdc-select__dropdown-icon': true,
      ...classNames(className)
    }, ...rest }, children));
};
const SelectDropdownIconGraphic = (props, children) => {
  const { class: className, ...rest } = props;
  return (h("svg", { xmlns: "http://www.w3.org/2000/svg", class: {
      'mdc-select__dropdown-icon-graphic': true,
      ...classNames(className)
    }, viewBox: '7 10 10 5', focusable: 'false', ...rest },
    h(SelectDropdownIconInactive, null),
    h(SelectDropdownIconActive, null),
    children));
};
const SelectDropdownIconInactive = (props, children) => {
  const { class: className, ...rest } = props;
  return (h("polygon", { class: {
      'mdc-select__dropdown-icon-inactive': true,
      ...classNames(className)
    }, stroke: 'none', "fill-rule": 'evenodd', points: '7 10 12 15 17 10', ...rest }, children));
};
const SelectDropdownIconActive = (props, children) => {
  const { class: className, ...rest } = props;
  return (h("polygon", { class: {
      'mdc-select__dropdown-icon-active': true,
      ...classNames(className)
    }, stroke: 'none', "fill-rule": 'evenodd', points: '7 15 12 10 17 15', ...rest }, children));
};
const SelectMenu = (props, children) => {
  const { class: className, ...rest } = props;
  return (h(Menu, { class: {
      'mdc-select__menu': true,
      ...classNames(className)
    }, ...rest }, children));
};

export { Select, SelectAnchor, SelectDropdownIcon, SelectDropdownIconGraphic, SelectMenu, SelectRipple, SelectSelectedText, SelectSelectedTextContainer };
